package svet.chovatelstvi.psi;
import svet.Clovek;
import svet.chovatelstvi.JineZvireNekoupiException;
import svet.chovatelstvi.ZvireNekoupiException;
import svet.chovatelstvi.NemaZvireException;
import junit.framework.TestCase;
import java.util.Iterator;
public class ChovatelPsuTest extends TestCase {
    private Pes asta, brok, vorisek;
    private ChovatelPsu petr, petra, rene;
    public ChovatelPsuTest(String name) {
        super(name);
    }
    // metoda "main" nen nezbytn, hod se vak
    // pro pohodln spoutn tohoto testu
    public static void main(String args[]) {
        junit.swingui.TestRunner.run(ChovatelPsuTest.class);
    }
    // vytvome psy a chovatele
    public void setUp() {
        asta = new LoveckyPes("Asta", "jezevcik");
        brok = new LoveckyPes("Brok", "foxterier");
        vorisek = new Vorisek("Vorisek");
        petr = new ChovatelPsu("Petr Novotny", Clovek.MUZ);
        petra = new ChovatelPsu("Petra Svobodova", Clovek.ZENA);
        rene = new ChovatelPsu("Rene Dvorak", Clovek.MUZ);
    }
    // test: po prodeji pvodn majitel psa nesm u mt
    public void testPoProdejiNema() {
        petr.vyradVsechnaZvirata();
        petra.vyradVsechnaZvirata();
        petr.zaradZvire(brok);
        petr.prodejZvire(brok, petra);
        assertTrue("Po prodeji nesmi pes patrit puvodnimu majiteli.",
                   !petr.maZvire(brok));
        assertTrue("Po prodeji musi pes patrit novemu majiteli.",
                   petra.maZvire(brok));
        assertEquals(petr.zvirata().size(), 0);
        assertEquals(petra.zvirata().size(), 1);
    }
    public void testNelzeZnovuProdat() {
        petr.vyradVsechnaZvirata();
        petra.vyradVsechnaZvirata();
        petr.zaradZvire(brok);
        petr.prodejZvire(brok, petra);
        try {
            petr.prodejZvire(brok, petra);
            fail("Tehoz psa nelze prodat dvakrat.");
        } catch (NemaZvireException nze) {  }
    }
    public void testNelzeProdatBezPP() {
        petr.vyradVsechnaZvirata();
        petra.vyradVsechnaZvirata();
        petr.zaradZvire(vorisek);
        try {
            petr.prodejZvire(vorisek, petra);
            fail("Nelze prodat psa bez PP.");
        } catch (ZvireNekoupiException nze) {  }
        assertTrue("Pes zustal pvodnmu majiteli.", petr.maZvire(vorisek));
        assertTrue("Kupujici psa nekoupi.", !petra.maZvire(vorisek));
    }
    public void testKoleckoProdeju() {
        petr.vyradVsechnaZvirata();
        petra.vyradVsechnaZvirata();
        rene.vyradVsechnaZvirata();
        petr.zaradZvire(brok);
        petr.prodejZvire(brok, petra);
        petra.prodejZvire(brok, rene);
        rene.prodejZvire(brok, petr);
        assertTrue("Pes je opet u puvodniho majitele.", petr.maZvire(brok));
        assertEquals(petr.zvirata().size(), 1);
        assertEquals(petra.zvirata().size(), 0);
        assertEquals(rene.zvirata().size(), 0);
    }
}